import { SchemaDefinition } from "untyped";
export interface DefinerModes {
    bytea: "ByteA" | "string" | "Buffer";
    /**
     * The bit definer mode.
     *
     * @default "string"
     */
    bit: "Bit" | "string" | "number";
    /**
     * The bit varying definer mode.
     *
     * @default "string"
     */
    bitVarying: "BitVarying" | "string" | "number";
    /**
     * The boolean definer mode.
     *
     * @default "boolean"
     */
    boolean: "Boolean" | "string" | "boolean" | "number";
    /**
     * The character definer mode.
     *
     * @default "string"
     */
    character: "Character" | "string";
    /**
     * The character varying definer mode.
     *
     * @default "string"
     */
    characterVarying: "CharacterVarying" | "string";
    /**
     * The char definer mode.
     *
     * @default "string"
     */
    name: "Name" | "string";
    /**
     * The text definer mode.
     *
     * @default "string"
     */
    text: "Text" | "string";
    /**
     * The date definer mode.
     *
     * @default "globalThis.Date"
     */
    date: "Date" | "globalThis.Date" | "luxon.DateTime" | "unix" | "string";
    /**
     * The date multi range definer mode.
     *
     * @default "string"
     */
    dateMultiRange: "DateMultiRange" | "string";
    /**
     * The date range definer mode.
     *
     * @default "string"
     */
    dateRange: "DateRange" | "string";
    /**
     * The interval definer mode.
     *
     * @default "string"
     */
    interval: "Interval" | "string";
    /**
     * The time definer mode.
     *
     * @default "globalThis.Date"
     */
    time: "Time" | "globalThis.Date" | "luxon.DateTime" | "unix" | "string";
    /**
     * The timestamp definer mode.
     *
     * @default "globalThis.Date"
     */
    timestamp: "Timestamp" | "globalThis.Date" | "luxon.DateTime" | "unix" | "string";
    /**
     * The timestamp multi range definer mode.
     *
     * @default "string"
     */
    timestampMultiRange: "TimestampMultiRange" | "string";
    /**
     * The timestamp range definer mode.
     *
     * @default "string"
     */
    timestampRange: "TimestampRange" | "string";
    /**
     * The timestamptz definer mode.
     *
     * @default "globalThis.Date"
     */
    timestamptz: "TimestampTZ" | "globalThis.Date" | "luxon.DateTime" | "unix" | "string";
    /**
     * The timestamptz multi range definer mode.
     *
     * @default "string"
     */
    timestamptzMultiRange: "TimestampTZMultiRange" | "string";
    /**
     * The timestamptz range definer mode.
     *
     * @default "string"
     */
    timestamptzRange: "TimestampTZRange" | "string";
    /**
     * The timetz definer mode.
     *
     * @default "globalThis.Date"
     */
    timetz: "TimeTZ" | "globalThis.Date" | "luxon.DateTime" | "unix" | "string";
    /**
     * The enum definer mode.
     *
     * @default "string"
     */
    enum: "Enum" | "string";
    /**
     * The box definer mode.
     *
     * @default "string"
     */
    box: "Box" | "string";
    /**
     * The circle definer mode.
     *
     * @default "string"
     */
    circle: "Circle" | "string";
    /**
     * The line definer mode.
     *
     * @default "string"
     */
    line: "Line" | "string";
    /**
     * The line segment definer mode.
     *
     * @default "string"
     */
    lineSegment: "LineSegment" | "string";
    /**
     * The path definer mode.
     *
     * @default "string"
     */
    path: "Path" | "string";
    /**
     * The point definer mode.
     *
     * @default "string"
     */
    point: "Point" | "string";
    /**
     * The polygon definer mode.
     *
     * @default "string"
     */
    polygon: "Polygon" | "string";
    /**
     * The json definer mode.
     *
     * @default "value"
     */
    json: "JSON" | "string" | "value";
    /**
     * The jsonb definer mode.
     *
     * @default "value"
     */
    jsonb: "JSON" | "string" | "value";
    /**
     * The money definer mode.
     *
     * @default "number"
     */
    money: "Money" | "string" | "BigNumber" | "number";
    /**
     * The float4 definer mode.
     *
     * @default "number"
     */
    float4: "Float4" | "string" | "BigNumber" | "number";
    /**
     * The float8 definer mode.
     *
     * @default "number"
     */
    float8: "Float8" | "string" | "BigNumber" | "number";
    /**
     * The int2 definer mode.
     *
     * @default "number"
     */
    int2: "Int2" | "string" | "number";
    /**
     * The int4 definer mode.
     *
     * @default "number"
     */
    int4: "Int4" | "string" | "number";
    /**
     * The int4 multi range definer mode.
     *
     * @default "string"
     */
    int4MultiRange: "Int4MultiRange" | "string";
    /**
     * The int4 range definer mode.
     *
     * @default "string"
     */
    int4Range: "Int4Range" | "string";
    /**
     * The int8 definer mode.
     *
     * @default "number"
     */
    int8: "Int8" | "string" | "BigInt" | "number";
    /**
     * The int8 multi range definer mode.
     *
     * @default "string"
     */
    int8MultiRange: "Int8MultiRange" | "string";
    /**
     * The int8 range definer mode.
     *
     * @default "string"
     */
    int8Range: "Int8Range" | "string";
    /**
     * The oid definer mode.
     *
     * @default "number"
     */
    oid: "OID" | "string" | "number";
    /**
     * The uuid definer mode.
     *
     * @default "string"
     */
    uuid: "UUID" | "string";
}
declare const schema: SchemaDefinition;
export default schema;
